==> mdm-rpc-0.1.17-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by danDy on 2017/5/9.
 */
public class OrgBasicInformationVo implements Serializable{
    private static final long serialVersionUID = -3791812526407168412L;
    private String id;
    //组织编码
    private String orgCode;
    //组织名称
    private String orgName;
    //组织层级编码
    private String orgHierarchyCode;
    //组织层级名称
    private String orgHierarchyName;
    //上级组织编码
    private String parentCode;
    //上级组织名称
    private String parentName;
    //SD组织编码
    private String sdOrgCode;
    //SD组织代码是否必须存在
    private String sdOrgMust;
    //SD组织单元类型标记
    private String sdOrgFlag;
    //更新时间
    private Date updateDate;
    //创建人
    private String createName;
    //有效开始时间
    private String validStartDate;
    //有效结束时间
    private String validEndDate;
    //组织状态
    private Integer enableStatus;
    //预算标识
    private String budgetFlag;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgHierarchyCode() {
        return orgHierarchyCode;
    }

    public void setOrgHierarchyCode(String orgHierarchyCode) {
        this.orgHierarchyCode = orgHierarchyCode;
    }

    public String getOrgHierarchyName() {
        return orgHierarchyName;
    }

    public void setOrgHierarchyName(String orgHierarchyName) {
        this.orgHierarchyName = orgHierarchyName;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getSdOrgCode() {
        return sdOrgCode;
    }

    public void setSdOrgCode(String sdOrgCode) {
        this.sdOrgCode = sdOrgCode;
    }

    public String getSdOrgMust() {
        return sdOrgMust;
    }

    public void setSdOrgMust(String sdOrgMust) {
        this.sdOrgMust = sdOrgMust;
    }

    public String getSdOrgFlag() {
        return sdOrgFlag;
    }

    public void setSdOrgFlag(String sdOrgFlag) {
        this.sdOrgFlag = sdOrgFlag;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(String validStartDate) {
        this.validStartDate = validStartDate;
    }

    public String getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(String validEndDate) {
        this.validEndDate = validEndDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getBudgetFlag() {
        return budgetFlag;
    }

    public void setBudgetFlag(String budgetFlag) {
        this.budgetFlag = budgetFlag;
    }
}

==> mdm-rpc-0.1.37-sources.jar: com/chinayanghe/msp/mdm/vo/org/OrgBasicInformationVo.java <==
package com.chinayanghe.msp.mdm.vo.org;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by danDy on 2017/5/9.
 */
public class OrgBasicInformationVo implements Serializable{
    private static final long serialVersionUID = -3791812526407168412L;
    private String id;
    //组织编码
    private String orgCode;
    //组织名称
    private String orgName;
    private String parentId;
    //组织层级编码
    private String orgHierarchyCode;
    //组织层级名称
    private String orgHierarchyName;
    //上级组织编码
    private String parentCode;
    //上级组织名称
    private String parentName;
    //SD组织编码
    private String sdOrgCode;
    //SD组织代码是否必须存在
    private String sdOrgMust;
    //SD组织单元类型标记
    private String sdOrgFlag;
    //更新时间
    private Date updateDate;
    //创建人
    private String createName;
    //有效开始时间
    private String validStartDate;
    //有效结束时间
    private String validEndDate;
    //组织状态
    private Integer enableStatus;
    //预算标识
    private String budgetFlag;

    //关联子组织
    private List<OrgBasicInformationVo> childOrgs;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgHierarchyCode() {
        return orgHierarchyCode;
    }

    public void setOrgHierarchyCode(String orgHierarchyCode) {
        this.orgHierarchyCode = orgHierarchyCode;
    }

    public String getOrgHierarchyName() {
        return orgHierarchyName;
    }

    public void setOrgHierarchyName(String orgHierarchyName) {
        this.orgHierarchyName = orgHierarchyName;
    }

    public String getParentCode() {
        return parentCode;
    }

    public void setParentCode(String parentCode) {
        this.parentCode = parentCode;
    }

    public String getParentName() {
        return parentName;
    }

    public void setParentName(String parentName) {
        this.parentName = parentName;
    }

    public String getSdOrgCode() {
        return sdOrgCode;
    }

    public void setSdOrgCode(String sdOrgCode) {
        this.sdOrgCode = sdOrgCode;
    }

    public String getSdOrgMust() {
        return sdOrgMust;
    }

    public void setSdOrgMust(String sdOrgMust) {
        this.sdOrgMust = sdOrgMust;
    }

    public String getSdOrgFlag() {
        return sdOrgFlag;
    }

    public void setSdOrgFlag(String sdOrgFlag) {
        this.sdOrgFlag = sdOrgFlag;
    }

    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public String getValidStartDate() {
        return validStartDate;
    }

    public void setValidStartDate(String validStartDate) {
        this.validStartDate = validStartDate;
    }

    public String getValidEndDate() {
        return validEndDate;
    }

    public void setValidEndDate(String validEndDate) {
        this.validEndDate = validEndDate;
    }

    public Integer getEnableStatus() {
        return enableStatus;
    }

    public void setEnableStatus(Integer enableStatus) {
        this.enableStatus = enableStatus;
    }

    public String getBudgetFlag() {
        return budgetFlag;
    }

    public void setBudgetFlag(String budgetFlag) {
        this.budgetFlag = budgetFlag;
    }

    public String getParentId() {
        return parentId;
    }

    public void setParentId(String parentId) {
        this.parentId = parentId;
    }

    public List<OrgBasicInformationVo> getChildOrgs() {
        return childOrgs;
    }

    public void setChildOrgs(List<OrgBasicInformationVo> childOrgs) {
        this.childOrgs = childOrgs;
    }
}
